"""init"""
from .ark_scrawl import *
from .ark_record import *
from .ark_operator import *
from .ark_update import *

__plugin_name__ = "nonebot_plugin_arkrecord"
__plguin_version__ = "1.7.0"